@@ -33,10 +33,17 @@
 //! ```
 
 mod context;
+mod core_function;
 mod plugin;
 mod video_context;
 pub use context::*;
+pub(crate) use core_function::*;
 pub use plugin::*;
 pub use video_context::*;
 
 pub use sdl2;
+
+pub(crate) fn log_sdl_version() {
+    let sdl_version = sdl2::version::version();
+    log::info!("Using SDL v{}", sdl_version);
+}
